.. liesym documentation master file, created by
   sphinx-quickstart on Thu Feb 25 17:06:27 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to liesym's documentation!
==================================

Liesym is an extension module on SymPy that reimplements the
liealgebra module inside sympy with the idea of using a
compiled backend to do speedups on some of the slower aspects
of SymPy's pure python implementation. This python module is
mostly a reimplementation of a Mathematica module LieART.


- SymPy: https://sympy.org
- LieART: https://arxiv.org/pdf/1206.6379.pdf


Module contents
---------------

.. toctree::
   :maxdepth: 4

   algebra
   group

==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


